@@ -277,14 +277,13 @@ def main():
     # Update ruuvi data every 5 minutes
     schedule.every(5).minutes.do(get_ruuvi_data)
 
-    application.start_polling()
+    application.updater.start_polling()
 
     while True:
         schedule.run_pending()
         time.sleep(1)
 
-    application.stop()
-
+    
 
 if __name__ == "__main__":
     main()
